==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/el-GR/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'Ένας χρήστης έχει αποδεχθεί ένα αντικείμενο',
    'acceptance_asset_declined' => 'Ένας χρήστης έχει απορρίψει ένα στοιχείο',
    'a_user_canceled' => 'Ένας χρήστης έχει ακυρώσει μια αίτηση στοιχείο στην ιστοσελίδα',
    'a_user_requested' => 'Ο χρήστης έχει ζητήσει ένα στοιχείο στην ιστοσελίδα',
    'accessory_name' => 'Όνομα ανταλλακτικού:',
    'additional_notes' => 'Πρόσθετες σημειώσεις:',
    'admin_has_created' => 'Ένας διαχειριστής έχει δημιουργήσει ένα λογαριασμό για εσάς στην: web ιστοσελίδα.',
    'asset' => 'Πάγιο:',
    'asset_name' => 'Όνομα του περιουσιακού στοιχείου:',
    'asset_requested' => 'Πάγιο αίτήθηκε',
    'asset_tag' => 'Ετικέτα παγίων',
    'assigned_to' => 'Ανατέθηκε στον',
    'best_regards' => 'Τις καλύτερες ευχές,',
    'canceled' => 'Ακυρωμένο:',
    'checkin_date' => 'Ημερομηνία άφιξης:',
    'checkout_date' => 'Ημερομηνία αποχώρησης:',
    'click_to_confirm' => 'Κάντε κλικ στον παρακάτω σύνδεσμο για να επιβεβαιώσετε τον λογαριασμό σας στο διαδίκτυο:',
    'click_on_the_link_accessory' => 'Κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε λάβει το αξεσουάρ.',
    'click_on_the_link_asset' => 'Κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε λάβει το στοιχείο.',
    'Confirm_Asset_Checkin' => 'Επιβεβαίωση στοιχείου ενεργητικού',
    'Confirm_Accessory_Checkin' => 'Επιβεβαίωση ελέγχου αξεσουάρ',
    'Confirm_accessory_delivery' => 'Επιβεβαίωση παράδοσης αξεσουάρ',
    'Confirm_license_delivery' => 'Επιβεβαίωση παράδοσης άδειας',
    'Confirm_asset_delivery' => 'Επιβεβαίωση παράδοσης παγίου',
    'Confirm_consumable_delivery' => 'Επιβεβαίωση αναλώσιμης παράδοσης',
    'current_QTY' => 'Τρέχουσα ποσότητα',
    'Days' => 'Ημέρες',
    'days' => 'Ημέρες',
    'expecting_checkin_date' => 'Αναμενόμενη ημερομηνία checkin:',
    'expires' => 'Λήξη',
    'Expiring_Assets_Report' => 'Αναφορά λήξης παγίων.',
    'Expiring_Licenses_Report' => 'Αναφορά λήξης αδειών.',
    'hello' => 'Γεια',
    'hi' => 'Γεια σας',
    'i_have_read' => 'Έχω διαβάσει και συμφωνώ με τους όρους χρήσης, και έχω λάβει αυτό το στοιχείο.',
    'item' => 'Αντικείμενο:',
    'Item_Request_Canceled' => 'Αίτηση στοιχείου ακυρώθηκε',
    'Item_Requested' => 'Στοιχείο που ζητήθηκε',
    'link_to_update_password' => 'Κάντε κλικ στον παρακάτω σύνδεσμο για να ενημερώσετε τον κωδικό: web:',
    'login_first_admin' => 'Συνδεθείτε στη νέα σας εγκατάσταση Snipe-IT χρησιμοποιώντας τα παρακάτω διαπιστευτήρια:',
    'login' => 'Σύνδεση:',
    'Low_Inventory_Report' => 'Αναφορά χαμηλού αποθέματος',
    'inventory_report' => 'Έκθεση Αποθέματος',
    'min_QTY' => 'Ελάχιστη ποσότητα',
    'name' => 'Όνομα',
    'new_item_checked' => 'Ένα νέο στοιχείο έχει ελεγχθεί με το όνομά σας, οι λεπτομέρειες είναι παρακάτω.',
    'password' => 'Κωδικός:',
    'password_reset' => 'Επαναφορά κωδικού πρόσβασης',

    'read_the_terms' => 'Παρακαλώ διαβάστε του παρακάτω όρους.',
    'read_the_terms_and_click' => 'Διαβάστε τους παρακάτω όρους χρήσης και κάντε κλικ στον σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε διαβάσει και συμφωνήσετε με τους όρους χρήσης και έχετε λάβει το στοιχείο.',
    'requested' => 'Ζητήθηκαν:',
    'reset_link' => 'Αποστολή συνδέσμου ακύρωσης κωδικού',
    'reset_password' => 'Κάντε κλικ εδώ για να επαναφέρετε τον κωδικό πρόσβασής σας:',
    'serial' => 'Σειριακός',
    'supplier' => 'Προμηθευτές',
    'tag' => 'Ετικέτα',
    'test_email' => 'Έλεγχος email για Snipe-IT',
    'test_mail_text' => 'Πρόκειται για μια δοκιμή από το σύστημα διαχείρισης περιουσιακών στοιχείων της Snipe-IT. Αν το έχετε, το mail λειτουργεί :)',
    'the_following_item' => 'Το παρακάτω στοιχείο έχει ελεγχθεί:',
    'low_inventory_alert' => 'Υπάρχει :count στοιχείο που είναι κάτω από το ελάχιστο απόθεμα ή σύντομα θα είναι χαμηλό. Υπάρχουν :count στοιχεία που είναι κάτω από το ελάχιστο απόθεμα ή σύντομα θα είναι χαμηλή.',
    'assets_warrantee_alert' => 'Υπάρχει :count περιουσιακό στοιχείο με μια εγγύηση που λήγει στις επόμενες :threshold days.°C. Υπάρχουν :count περιουσιακά στοιχεία με εγγυήσεις που λήγουν στις επόμενες :threshold ημέρες.',
    'license_expiring_alert' => 'Υπάρχει :count άδεια που λήγει στις επόμενες :threshold ημέρες."Υπάρχουν :count άδειες που λήγουν στις επόμενες :threshold ημέρες.',
    'to_reset' => 'Για να επαναφέρετε τον κωδικό πρόσβασης στον ιστό, συμπληρώστε αυτήν τη φόρμα:',
    'type' => 'Τύπος',
    'upcoming-audits' => 'Υπάρχει :count περιουσιακό στοιχείο που έρχεται για έλεγχο μέσα σε :threshold days.°C. Υπάρχουν :count περιουσιακά στοιχεία που έρχονται για έλεγχο εντός :threshold ημερών.',
    'user' => 'Χρήστης',
    'username' => 'Όνομα χρήστη',
    'welcome' => 'Καλώς ήρθατε, %name',
    'welcome_to' => 'Καλώς ήλθατε στο!',
    'your_credentials' => 'Τα διαπιστευτήρια σας Snipe-IT',
    'Accessory_Checkin_Notification' => 'Το αξεσουάρ επανήλθε',
    'Asset_Checkin_Notification' => 'Το περιουσιακό στοιχείο ολοκληρώθηκε',
    'Asset_Checkout_Notification' => 'Το περιουσιακό στοιχείο ολοκληρώθηκε',
    'License_Checkin_Notification' => 'Η άδεια επανήλθε',
    'Expected_Checkin_Report' => 'Αναμενόμενη αναφορά ελέγχου στοιχείων ενεργητικού',
    'Expected_Checkin_Notification' => 'Υπενθύμιση: πλησιάζει η προθεσμία :name checkin',
    'Expected_Checkin_Date' => 'Ένα στοιχείο που αποδεσμεύθηκε για εσάς αναμένεται να ελεγχθεί ξανά στις :date',
    'your_assets' => 'Προβολή Των Αντικειμένων Σας',
    'rights_reserved' => 'Με επιφύλαξη παντός δικαιώματος.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/el-GR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Το αξεσουάρ επανήλθε',
    'Accessory_Checkout_Notification' => 'Το αξεσουάρ ελέγχθηκε',
    'Asset_Checkin_Notification' => 'Το περιουσιακό στοιχείο ολοκληρώθηκε',
    'Asset_Checkout_Notification' => 'Το περιουσιακό στοιχείο ολοκληρώθηκε',
    'Confirm_Accessory_Checkin' => 'Επιβεβαίωση ελέγχου αξεσουάρ',
    'Confirm_Asset_Checkin' => 'Επιβεβαίωση στοιχείου ενεργητικού',
    'Confirm_accessory_delivery' => 'Επιβεβαίωση παράδοσης αξεσουάρ',
    'Confirm_asset_delivery' => 'Επιβεβαίωση παράδοσης παγίου',
    'Confirm_consumable_delivery' => 'Επιβεβαίωση αναλώσιμης παράδοσης',
    'Confirm_license_delivery' => 'Επιβεβαίωση παράδοσης άδειας',
    'Consumable_checkout_notification' => 'Το αναλώσιμο έχει ελεγχθεί',
    'Days' => 'Ημέρες',
    'Expected_Checkin_Date' => 'Ένα στοιχείο που αποδεσμεύθηκε για εσάς αναμένεται να ελεγχθεί ξανά στις :date',
    'Expected_Checkin_Notification' => 'Υπενθύμιση: πλησιάζει η προθεσμία :name checkin',
    'Expected_Checkin_Report' => 'Αναμενόμενη αναφορά ελέγχου στοιχείων ενεργητικού',
    'Expiring_Assets_Report' => 'Αναφορά λήξης παγίων.',
    'Expiring_Licenses_Report' => 'Αναφορά λήξης αδειών.',
    'Item_Request_Canceled' => 'Αίτηση στοιχείου ακυρώθηκε',
    'Item_Requested' => 'Στοιχείο που ζητήθηκε',
    'License_Checkin_Notification' => 'Η άδεια επανήλθε',
    'License_Checkout_Notification' => 'Η άδεια έχει ελεγχθεί',
    'Low_Inventory_Report' => 'Αναφορά χαμηλού αποθέματος',
    'a_user_canceled' => 'Ένας χρήστης έχει ακυρώσει μια αίτηση στοιχείο στην ιστοσελίδα',
    'a_user_requested' => 'Ο χρήστης έχει ζητήσει ένα στοιχείο στην ιστοσελίδα',
    'acceptance_asset_accepted' => 'Ένας χρήστης έχει αποδεχθεί ένα αντικείμενο',
    'acceptance_asset_declined' => 'Ένας χρήστης έχει απορρίψει ένα στοιχείο',
    'accessory_name' => 'Όνομα ανταλλακτικού:',
    'additional_notes' => 'Πρόσθετες σημειώσεις:',
    'admin_has_created' => 'Ένας διαχειριστής έχει δημιουργήσει ένα λογαριασμό για εσάς στην: web ιστοσελίδα.',
    'asset' => 'Πάγιο:',
    'asset_name' => 'Όνομα του περιουσιακού στοιχείου:',
    'asset_requested' => 'Πάγιο αίτήθηκε',
    'asset_tag' => 'Ετικέτα παγίων',
    'assets_warrantee_alert' => 'Υπάρχει :count περιουσιακό στοιχείο με μια εγγύηση που λήγει στις επόμενες :threshold days.°C. Υπάρχουν :count περιουσιακά στοιχεία με εγγυήσεις που λήγουν στις επόμενες :threshold ημέρες.',
    'assigned_to' => 'Ανατέθηκε στον',
    'best_regards' => 'Τις καλύτερες ευχές,',
    'canceled' => 'Ακυρωμένο:',
    'checkin_date' => 'Ημερομηνία άφιξης:',
    'checkout_date' => 'Ημερομηνία αποχώρησης:',
    'checkedout_from' => 'Έγινε έλεγχος από',
    'checkedin_from'  => 'Έγινε έλεγχος από',
    'checked_into' => 'Έγινε έλεγχος',
    'click_on_the_link_accessory' => 'Κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε λάβει το αξεσουάρ.',
    'click_on_the_link_asset' => 'Κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι έχετε λάβει το στοιχείο.',
    'click_to_confirm' => 'Κάντε κλικ στον παρακάτω σύνδεσμο για να επιβεβαιώσετε τον λογαριασμό σας στο διαδίκτυο:',
    'current_QTY' => 'Τρέχουσα ποσότητα',
    'days' => 'Ημέρες',
    'expecting_checkin_date' => 'Αναμενόμενη ημερομηνία checkin:',
    'expires' => 'Λήξη',
    'hello' => 'Γεια',
    'hi' => 'Γεια σας',
    'i_have_read' => 'Έχω διαβάσει και συμφωνώ με τους όρους χρήσης, και έχω λάβει αυτό το στοιχείο.',
    'inventory_report' => 'Έκθεση Αποθέματος',
    'item' => 'Αντικείμενο:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Υπάρχει :count άδεια που λήγει στις επόμενες :threshold ημέρες."Υπάρχουν :count άδειες που λήγουν στις επόμενες :threshold ημέρες.',
    'link_to_update_password' => 'Κάντε κλικ στον παρακάτω σύνδεσμο για να ενημερώσετε τον κωδικό: web:',
    'login' => 'Σύνδεση:',
    'login_first_admin' => 'Συνδεθείτε στη νέα σας εγκατάσταση Snipe-IT χρησιμοποιώντας τα παρακάτω διαπιστευτήρια:',
    'low_inventory_alert' => 'Υπάρχει :count στοιχείο που είναι κάτω από το ελάχιστο απόθεμα ή σύντομα θα είναι χαμηλό. Υπάρχουν :count στοιχεία που είναι κάτω από το ελάχιστο απόθεμα ή σύντομα θα είναι χαμηλή.',
    'min_QTY' => 'Ελάχιστη ποσότητα',
    'name' => 'Όνομα',
    'new_item_checked' => 'Ένα νέο στοιχείο έχει ελεγχθεί με το όνομά σας, οι λεπτομέρειες είναι παρακάτω.',
    'notes' => 'Σημειώσεις',
    'password' => 'Κωδικός:',
    'password_reset' => 'Επαναφορά κωδικού πρόσβασης',
    'read_the_terms' => 'Παρακαλώ διαβάστε του παρακάτω όρους.',
    'read_the_terms_and_click' => 'Παρακαλούμε διαβάστε τους όρους χρήσης παρακάτω, και κάντε κλικ στο σύνδεσμο στο κάτω μέρος για να επιβεβαιώσετε ότι διαβάζετε και συμφωνείτε με τους όρους χρήσης και έχετε λάβει το περιουσιακό στοιχείο.',
    'requested' => 'Ζητήθηκαν:',
    'reset_link' => 'Αποστολή συνδέσμου ακύρωσης κωδικού',
    'reset_password' => 'Κάντε κλικ εδώ για να επαναφέρετε τον κωδικό πρόσβασής σας:',
    'rights_reserved' => 'Με επιφύλαξη παντός δικαιώματος.',
    'serial' => 'Σειριακός',
    'snipe_webhook_test' => 'Snipe-IT Δοκιμή Ολοκλήρωσης',
    'snipe_webhook_summary' => 'Σύνοψη Δοκιμής Ενσωμάτωσης Snipe-IT',
    'supplier' => 'Προμηθευτές',
    'tag' => 'Ετικέτα',
    'test_email' => 'Έλεγχος email για Snipe-IT',
    'test_mail_text' => 'Πρόκειται για μια δοκιμή από το σύστημα διαχείρισης περιουσιακών στοιχείων της Snipe-IT. Αν το έχετε, το mail λειτουργεί :)',
    'the_following_item' => 'Το παρακάτω στοιχείο έχει ελεγχθεί:',
    'to_reset' => 'Για να επαναφέρετε τον κωδικό πρόσβασης στον ιστό, συμπληρώστε αυτήν τη φόρμα:',
    'type' => 'Τύπος',
    'upcoming-audits' => 'Υπάρχει :count περιουσιακό στοιχείο που έρχεται για έλεγχο μέσα σε :threshold days.°C. Υπάρχουν :count περιουσιακά στοιχεία που έρχονται για έλεγχο εντός :threshold ημερών.',
    'user' => 'Χρήστης',
    'username' => 'Όνομα χρήστη',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Καλώς ήρθατε, %name',
    'welcome_to' => 'Καλώς ήλθατε στο!',
    'your_assets' => 'Προβολή Των Αντικειμένων Σας',
    'your_credentials' => 'Τα διαπιστευτήρια σας Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
